var regexes = {
    /**
     * Number
     * 
     * Example: 1234567890
     */
    Number: /[0-9]+/,
    
    /**
     * String
     * 
     * Example: "Hello, World!"
     */
    String: /".*"/,

    /**
     * Symbol
     * 
     * Example: !
     */
    Symbol: /[!-\/:-@[-`{-~]/,

    /**
     * Email
     * 
     * Example: email@example.com
     */
    Email: /\\w+([\\.-]?\\w+)*@\\w+([\\.-]?\\w+)*(\\.\\w{2,3})+$/,

    /**
     * Text
     * 
     * Example: Hello, World!
     */
    Text: /[a-zA-Z]*[0-9]*[ ]*/,

    /**
     * IPV4
     * 
     * Example: [none]
     */
    IPV4: /^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])$/,
    
    /**
     * IPV6
     * 
     * Example: [none]
     */
    IPV6: /(([0-9a-fA-F]{1,4}:){7,7}[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,7}:|([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}|([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}|([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}|([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}|[0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})|:((:[0-9a-fA-F]{1,4}){1,7}|:)|fe80:(:[0-9a-fA-F]{0,4}){0,4}%[0-9a-zA-Z]{1,}|::(ffff(:0{1,4}){0,1}:){0,1}((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])|([0-9a-fA-F]{1,4}:){1,4}:((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9]))/,

    /**
     * PhoneNumber
     * 
     * Example: 123-567-8901 or +1123-567-8901
     */
    PhoneNumber: /^(?:(?:\(?(?:00|\+)([1-4]\d\d|[1-9]\d?)\)?)?[\-\.\ \\\/]?)?((?:\(?\d{1,}\)?[\-\.\ \\\/]?){0,})(?:[\-\.\ \\\/]?(?:#|ext\.?|extension|x)[\-\.\ \\\/]?(\d+))?$/,

    /**
     * Password
     * 
     * Example: A&CdEfGh1jk
     */
    Password: /(?=(.*[0-9]))(?=.*[\!@#$%^&*()\\[\]{}\-_+=~`|:;"'<>,./?])(?=.*[a-z])(?=(.*[A-Z]))(?=(.*)).{8,}/,

    /**
     * JavascriptKeyword
     * 
     * Example: function
     */
    JavascriptKeyword: /(\barguments\b|\bawait\b|\bbreak\b|\bcase\b|\bcatch\b|\bclass\b|\bconst\b|\bcontinue\b|\bdebugger\b|\bdefault\b|\bdelete\b|\bdo\b|\belse\b|\bexport\b|\bextends\b|\bfalse\b|\bfinally\b|\bfor\b|\bfunction\b|\bgoto\b|\bif\b|\bimplements\b|\bimport\b|\bin\b|\binstanceof\b|\blet\b|\bnew\b|\bnull\b|\bpackage\b|\breturn\b|\bsuper\b|\bswitch\b|\bthis\b|\bthrow\b|\btrue\b|\btry\b|\btry\b|\btypeof\b|\bvar\b|\bwhile\b|\bwith\b|\byield\b)/,
    
    /**
     * HtmlTag
     * 
     * Example: <h1>Hello, World!</h1>
     */
    HtmlTag: /<.*>.*<\/.*>/
}   

module.exports = regexes
